@@ -11,10 +11,10 @@ Be creative! do whatever you want!
 
 def main():  # pragma: no cover
     from argparse import ArgumentParser
-    from pytorrentsearch.search import yandex, google, duckduckgo
+
+    from pytorrentsearch.miner import mine_magnet_links, prettyprint_magnet
+    from pytorrentsearch.search import duckduckgo, google, yandex
     from pytorrentsearch.utils import multi_iterator_pooler
-    from pytorrentsearch.miner import mine_magnet_links
-    from pytorrentsearch.miner import prettyprint_magnet
 
     parser = ArgumentParser("pytorrentsearch")
     parser.add_argument("query", type=str)
