@@ -5,7 +5,8 @@ LINK_REGEXP = re.compile('<a [^>]*href="([^"]*)"')
 
 def query_results(query: str, page=1):
     from urllib.parse import quote
-    from pytorrentsearch.utils import get_url_content, status, min_wait
+
+    from pytorrentsearch.utils import get_url_content, min_wait, status
 
     page_links: set[str] = set()
     min_waiter = min_wait(5)
@@ -14,7 +15,7 @@ def query_results(query: str, page=1):
             yield link
         next(min_waiter)
         status("Fetching Google result page...")
-        search_url = f"https://www.google.com/search?q={quote(query)}&start={(page-1)*20}"  # noqa: E501
+        search_url = f"https://www.google.com/search?q={quote(query)}&start={(page - 1) * 20}"  # noqa: E501
         content = get_url_content(search_url)
         page_links = set()
         for link in LINK_REGEXP.findall(content):
